@@ -22,11 +22,13 @@ from volatility3.framework import constants, exceptions, interfaces
 
 vollog = logging.getLogger(__name__)
 
-ProgressValue = Union['DummyProgress', multiprocessing.managers.ValueProxy]
+ProgressValue = Union["DummyProgress", multiprocessing.managers.ValueProxy]
 IteratorValue = Tuple[List[Tuple[str, int, int]], int]
 
 
-class ScannerInterface(interfaces.configuration.VersionableInterface, metaclass = ABCMeta):
+class ScannerInterface(
+    interfaces.configuration.VersionableInterface, metaclass=ABCMeta
+):
     """Class for layer scanners that return locations of particular values from
     within the data.
 
@@ -52,6 +54,7 @@ class ScannerInterface(interfaces.configuration.VersionableInterface, metaclass
     in either their own class or the context.  This will allow the scanner to be run
     in parallel against multiple blocks.
     """
+
     thread_safe = False
 
     _required_framework_version = (2, 0, 0)
@@ -64,11 +67,11 @@ class ScannerInterface(interfaces.configuration.VersionableInterface, metaclass
         self._layer_name: Optional[str] = None
 
     @property
-    def context(self) -> Optional['interfaces.context.ContextInterface']:
+    def context(self) -> Optional["interfaces.context.ContextInterface"]:
         return self._context
 
     @context.setter
-    def context(self, ctx: 'interfaces.context.ContextInterface') -> None:
+    def context(self, ctx: "interfaces.context.ContextInterface") -> None:
         """Stores the context locally in case the scanner needs to access the
         layer."""
         self._context = ctx
@@ -94,20 +97,24 @@ class ScannerInterface(interfaces.configuration.VersionableInterface, metaclass
         """
 
 
-class DataLayerInterface(interfaces.configuration.ConfigurableInterface, metaclass = ABCMeta):
+class DataLayerInterface(
+    interfaces.configuration.ConfigurableInterface, metaclass=ABCMeta
+):
     """A Layer that directly holds data (and does not translate it).
 
     This is effectively a leaf node in a layer tree. It directly
     accesses a data source and exposes it within volatility.
     """
 
-    _direct_metadata: Mapping = {'architecture': 'Unknown', 'os': 'Unknown'}
+    _direct_metadata: Mapping = {"architecture": "Unknown", "os": "Unknown"}
 
-    def __init__(self,
-                 context: 'interfaces.context.ContextInterface',
-                 config_path: str,
-                 name: str,
-                 metadata: Optional[Dict[str, Any]] = None) -> None:
+    def __init__(
+        self,
+        context: "interfaces.context.ContextInterface",
+        config_path: str,
+        name: str,
+        metadata: Optional[Dict[str, Any]] = None,
+    ) -> None:
         super().__init__(context, config_path)
         self._name = name
         self._metadata = metadata or {}
@@ -199,11 +206,13 @@ class DataLayerInterface(interfaces.configuration.ConfigurableInterface, metacla
 
     # ## General scanning methods
 
-    def scan(self,
-             context: interfaces.context.ContextInterface,
-             scanner: ScannerInterface,
-             progress_callback: constants.ProgressCallback = None,
-             sections: Iterable[Tuple[int, int]] = None) -> Iterable[Any]:
+    def scan(
+        self,
+        context: interfaces.context.ContextInterface,
+        scanner: ScannerInterface,
+        progress_callback: constants.ProgressCallback = None,
+        sections: Iterable[Tuple[int, int]] = None,
+    ) -> Iterable[Any]:
         """Scans a Translation layer by chunk.
 
         Note: this will skip missing/unmappable chunks of memory
@@ -224,7 +233,9 @@ class DataLayerInterface(interfaces.configuration.ConfigurableInterface, metacla
         scanner.layer_name = self.name
 
         if sections is None:
-            sections = [(self.minimum_address, self.maximum_address - self.minimum_address)]
+            sections = [
+                (self.minimum_address, self.maximum_address - self.minimum_address)
+            ]
 
         sections = list(self._coalesce_sections(sections))
 
@@ -232,13 +243,18 @@ class DataLayerInterface(interfaces.configuration.ConfigurableInterface, metacla
             progress: ProgressValue = DummyProgress()
             scan_iterator = functools.partial(self._scan_iterator, scanner, sections)
             scan_metric = self._scan_metric(scanner, sections)
-            if not scanner.thread_safe or constants.PARALLELISM == constants.Parallelism.Off:
+            if (
+                not scanner.thread_safe
+                or constants.PARALLELISM == constants.Parallelism.Off
+            ):
                 progress = DummyProgress()
                 scan_chunk = functools.partial(self._scan_chunk, scanner, progress)
                 for value in scan_iterator():
                     if progress_callback:
-                        progress_callback(scan_metric(progress.value),
-                                          f"Scanning {self.name} using {scanner.__class__.__name__}")
+                        progress_callback(
+                            scan_metric(progress.value),
+                            f"Scanning {self.name} using {scanner.__class__.__name__}",
+                        )
                     yield from scan_chunk(value)
             else:
                 progress = multiprocessing.Manager().Value("Q", 0)
@@ -252,8 +268,10 @@ class DataLayerInterface(interfaces.configuration.ConfigurableInterface, metacla
                     while not result.ready():
                         if progress_callback:
                             # Run the progress_callback
-                            progress_callback(scan_metric(progress.value),
-                                              f"Scanning {self.name} using {scanner.__class__.__name__}")
+                            progress_callback(
+                                scan_metric(progress.value),
+                                f"Scanning {self.name} using {scanner.__class__.__name__}",
+                            )
                         # Ensures we don't burn CPU cycles going round in a ready waiting loop
                         # without delaying the user too long between progress updates/results
                         result.wait(0.1)
@@ -262,15 +280,21 @@ class DataLayerInterface(interfaces.configuration.ConfigurableInterface, metacla
         except Exception as e:
             # We don't care the kind of exception, so catch and report on everything, yielding nothing further
             vollog.debug(f"Scan Failure: {str(e)}")
-            vollog.log(constants.LOGLEVEL_VVV,
-                       "\n".join(traceback.TracebackException.from_exception(e).format(chain = True)))
+            vollog.log(
+                constants.LOGLEVEL_VVV,
+                "\n".join(
+                    traceback.TracebackException.from_exception(e).format(chain=True)
+                ),
+            )
 
-    def _coalesce_sections(self, sections: Iterable[Tuple[int, int]]) -> Iterable[Tuple[int, int]]:
+    def _coalesce_sections(
+        self, sections: Iterable[Tuple[int, int]]
+    ) -> Iterable[Tuple[int, int]]:
         """Take a list of (start, length) sections and coalesce any adjacent
         sections."""
         result: List[Tuple[int, int]] = []
         position = 0
-        for (start, length) in sorted(sections):
+        for start, length in sorted(sections):
             if result and start <= position:
                 initial_start, _ = result.pop()
                 result.append((initial_start, (start + length) - initial_start))
@@ -283,7 +307,10 @@ class DataLayerInterface(interfaces.configuration.ConfigurableInterface, metacla
             if first_start + first_length < self.minimum_address:
                 result = result[1:]
             elif first_start < self.minimum_address:
-                result[0] = (self.minimum_address, (first_start + first_length) - self.minimum_address)
+                result[0] = (
+                    self.minimum_address,
+                    (first_start + first_length) - self.minimum_address,
+                )
         while result and result[-1] > (self.maximum_address, 0):
             last_start, last_length = result[-1]
             if last_start > self.maximum_address:
@@ -292,8 +319,9 @@ class DataLayerInterface(interfaces.configuration.ConfigurableInterface, metacla
                 result[1] = (last_start, self.maximum_address - last_start)
         return result
 
-    def _scan_iterator(self, scanner: 'ScannerInterface', sections: Iterable[Tuple[int,
-                                                                                   int]]) -> Iterable[IteratorValue]:
+    def _scan_iterator(
+        self, scanner: "ScannerInterface", sections: Iterable[Tuple[int, int]]
+    ) -> Iterable[IteratorValue]:
         """Iterator that indicates which blocks in the layer are to be read by
         for the scanning.
 
@@ -303,11 +331,16 @@ class DataLayerInterface(interfaces.configuration.ConfigurableInterface, metacla
         assumed to have no holes
         """
         for section_start, section_length in sections:
-            offset, mapped_offset, length, layer_name = section_start, section_start, section_length, self.name
+            offset, mapped_offset, length, layer_name = (
+                section_start,
+                section_start,
+                section_length,
+                self.name,
+            )
             while length > 0:
                 chunk_size = min(length, scanner.chunk_size + scanner.overlap)
                 yield [(layer_name, mapped_offset, chunk_size)], offset + chunk_size
-                # It we've got more than the scanner's chunk_size, only move up by the chunk_size
+                # If we've got more than the scanner's chunk_size, only move up by the chunk_size
                 if chunk_size > scanner.chunk_size:
                     chunk_size -= scanner.overlap
                 length -= chunk_size
@@ -315,16 +348,23 @@ class DataLayerInterface(interfaces.configuration.ConfigurableInterface, metacla
                 offset += chunk_size
 
     # We ignore the type due to the iterator_value, actually it only needs to match the output from _scan_iterator
-    def _scan_chunk(self, scanner: 'ScannerInterface', progress: 'ProgressValue',
-                    iterator_value: IteratorValue) -> List[Any]:
+    def _scan_chunk(
+        self,
+        scanner: "ScannerInterface",
+        progress: "ProgressValue",
+        iterator_value: IteratorValue,
+    ) -> List[Any]:
         data_to_scan, chunk_end = iterator_value
-        data = b''
+        data = b""
         for layer_name, address, chunk_size in data_to_scan:
             try:
                 data += self.context.layers[layer_name].read(address, chunk_size)
             except exceptions.InvalidAddressException:
-                vollog.debug("Invalid address in layer {} found scanning {} at address {:x}".format(
-                    layer_name, self.name, address))
+                vollog.debug(
+                    "Invalid address in layer {} found scanning {} at address {:x}".format(
+                        layer_name, self.name, address
+                    )
+                )
 
         if len(data) > scanner.chunk_size + scanner.overlap:
             vollog.debug(f"Scan chunk too large: {hex(len(data))}")
@@ -332,8 +372,9 @@ class DataLayerInterface(interfaces.configuration.ConfigurableInterface, metacla
         progress.value = chunk_end
         return list(scanner(data, chunk_end - len(data)))
 
-    def _scan_metric(self, _scanner: 'ScannerInterface', sections: List[Tuple[int, int]]) -> Callable[[int], float]:
-
+    def _scan_metric(
+        self, _scanner: "ScannerInterface", sections: List[Tuple[int, int]]
+    ) -> Callable[[int], float]:
         if not sections:
             raise ValueError("Sections have no size, nothing to scan")
         last_section, last_length = sections[-1]
@@ -357,11 +398,15 @@ class DataLayerInterface(interfaces.configuration.ConfigurableInterface, metacla
     @property
     def metadata(self) -> Mapping:
         """Returns a ReadOnly copy of the metadata published by this layer."""
-        maps = [self.context.layers[layer_name].metadata for layer_name in self.dependencies]
-        return interfaces.objects.ReadOnlyMapping(collections.ChainMap(self._metadata, self._direct_metadata, *maps))
+        maps = [
+            self.context.layers[layer_name].metadata for layer_name in self.dependencies
+        ]
+        return interfaces.objects.ReadOnlyMapping(
+            collections.ChainMap(self._metadata, self._direct_metadata, *maps)
+        )
 
 
-class TranslationLayerInterface(DataLayerInterface, metaclass = ABCMeta):
+class TranslationLayerInterface(DataLayerInterface, metaclass=ABCMeta):
     """Provides a layer that translates or transforms another layer or layers.
 
     Translation layers always depend on another layer (typically
@@ -370,10 +415,9 @@ class TranslationLayerInterface(DataLayerInterface, metaclass = ABCMeta):
     """
 
     @abstractmethod
-    def mapping(self,
-                offset: int,
-                length: int,
-                ignore_errors: bool = False) -> Iterable[Tuple[int, int, int, int, str]]:
+    def mapping(
+        self, offset: int, length: int, ignore_errors: bool = False
+    ) -> Iterable[Tuple[int, int, int, int, str]]:
         """Returns a sorted iterable of (offset, sublength, mapped_offset, mapped_length, layer)
         mappings.
 
@@ -390,7 +434,9 @@ class TranslationLayerInterface(DataLayerInterface, metaclass = ABCMeta):
         """Returns a list of layer names that this layer translates onto."""
         return []
 
-    def _decode_data(self, data: bytes, mapped_offset: int, offset: int, output_length: int) -> bytes:
+    def _decode_data(
+        self, data: bytes, mapped_offset: int, offset: int, output_length: int
+    ) -> bytes:
         """Decodes any necessary data.  Note, additional data may need to be read from the lower layer, such as lookup
         tables or similar.  The data provided to this layer is purely that data which encompasses the requested data
         range.
@@ -405,7 +451,9 @@ class TranslationLayerInterface(DataLayerInterface, metaclass = ABCMeta):
              The data to be read from the underlying layer."""
         return data
 
-    def _encode_data(self, layer_name: str, mapped_offset: int, offset: int, value: bytes) -> bytes:
+    def _encode_data(
+        self, layer_name: str, mapped_offset: int, offset: int, value: bytes
+    ) -> bytes:
         """Encodes any necessary data.
 
         Args:
@@ -420,28 +468,41 @@ class TranslationLayerInterface(DataLayerInterface, metaclass = ABCMeta):
 
     # ## Read/Write functions for mapped pages
 
-    @functools.lru_cache(maxsize = 512)
+    @functools.lru_cache(maxsize=512)
     def read(self, offset: int, length: int, pad: bool = False) -> bytes:
         """Reads an offset for length bytes and returns 'bytes' (not 'str') of
         length size."""
         current_offset = offset
-        output: bytes = b''
-        for (layer_offset, sublength, mapped_offset, mapped_length, layer) in self.mapping(offset,
-                                                                                           length,
-                                                                                           ignore_errors = pad):
+        output: bytes = b""
+        for (
+            layer_offset,
+            sublength,
+            mapped_offset,
+            mapped_length,
+            layer,
+        ) in self.mapping(offset, length, ignore_errors=pad):
             if not pad and layer_offset > current_offset:
                 raise exceptions.InvalidAddressException(
-                    self.name, current_offset, f"Layer {self.name} cannot map offset: {current_offset}")
+                    self.name,
+                    current_offset,
+                    f"Layer {self.name} cannot map offset: {current_offset}",
+                )
             elif layer_offset > current_offset:
                 output += b"\x00" * (layer_offset - current_offset)
                 current_offset = layer_offset
             # The layer_offset can be less than the current_offset in non-linearly mapped layers
             # it does not suggest an overlap, but that the data is in an encoded block
             if mapped_length > 0:
-                unprocessed_data = self._context.layers.read(layer, mapped_offset, mapped_length, pad)
-                processed_data = self._decode_data(unprocessed_data, mapped_offset, layer_offset, sublength)
+                unprocessed_data = self._context.layers.read(
+                    layer, mapped_offset, mapped_length, pad
+                )
+                processed_data = self._decode_data(
+                    unprocessed_data, mapped_offset, layer_offset, sublength
+                )
                 if len(processed_data) != sublength:
-                    raise ValueError("ProcessedData length does not match expected length of chunk")
+                    raise ValueError(
+                        "ProcessedData length does not match expected length of chunk"
+                    )
                 output += processed_data
                 current_offset += sublength
         return output + (b"\x00" * (length - len(output)))
@@ -451,21 +512,36 @@ class TranslationLayerInterface(DataLayerInterface, metaclass = ABCMeta):
         underlying mapping."""
         current_offset = offset
         length = len(value)
-        for (layer_offset, sublength, mapped_offset, mapped_length, layer) in self.mapping(offset, length):
+        for (
+            layer_offset,
+            sublength,
+            mapped_offset,
+            mapped_length,
+            layer,
+        ) in self.mapping(offset, length):
             if layer_offset > current_offset:
                 raise exceptions.InvalidAddressException(
-                    self.name, current_offset, f"Layer {self.name} cannot map offset: {current_offset}")
+                    self.name,
+                    current_offset,
+                    f"Layer {self.name} cannot map offset: {current_offset}",
+                )
 
-            value_chunk = value[layer_offset - offset:layer_offset - offset + sublength]
-            new_data = self._encode_data(layer, mapped_offset, layer_offset, value_chunk)
+            value_chunk = value[
+                layer_offset - offset : layer_offset - offset + sublength
+            ]
+            new_data = self._encode_data(
+                layer, mapped_offset, layer_offset, value_chunk
+            )
             self._context.layers.write(layer, mapped_offset, new_data)
 
             current_offset += len(new_data)
 
-    def _scan_iterator(self,
-                       scanner: 'ScannerInterface',
-                       sections: Iterable[Tuple[int, int]],
-                       linear: bool = False) -> Iterable[IteratorValue]:
+    def _scan_iterator(
+        self,
+        scanner: "ScannerInterface",
+        sections: Iterable[Tuple[int, int]],
+        linear: bool = False,
+    ) -> Iterable[IteratorValue]:
         """Iterator that indicates which blocks in the layer are to be read by
         for the scanning.
 
@@ -474,7 +550,7 @@ class TranslationLayerInterface(DataLayerInterface, metaclass = ABCMeta):
         scanner.chunk_size + scanner.overlap DataLayers by default are
         assumed to have no holes
         """
-        for (section_start, section_length) in sections:
+        for section_start, section_length in sections:
             output: List[Tuple[str, int, int]] = []
 
             # Hold the offsets of each chunk (including how much has been filled)
@@ -483,7 +559,9 @@ class TranslationLayerInterface(DataLayerInterface, metaclass = ABCMeta):
             # For each section, find out which bits of its exists and where they map to
             # This is faster than cutting the entire space into scan_chunk sized blocks and then
             # finding out what exists (particularly if most of the space isn't mapped)
-            for mapped in self.mapping(section_start, section_length, ignore_errors = True):
+            for mapped in self.mapping(
+                section_start, section_length, ignore_errors=True
+            ):
                 offset, sublength, mapped_offset, mapped_length, layer_name = mapped
 
                 # Setup the variables for this block
@@ -506,7 +584,10 @@ class TranslationLayerInterface(DataLayerInterface, metaclass = ABCMeta):
 
                 # Halfway through a chunk, finish the chunk, then take more
                 if chunk_position != chunk_start:
-                    chunk_size = min(chunk_position - chunk_start, scanner.chunk_size + scanner.overlap)
+                    chunk_size = min(
+                        chunk_position - chunk_start,
+                        scanner.chunk_size + scanner.overlap,
+                    )
                     output += [(return_name, chunk_position + conversion, chunk_size)]
                     chunk_start = chunk_position + chunk_size
                     chunk_position = chunk_start
@@ -517,10 +598,14 @@ class TranslationLayerInterface(DataLayerInterface, metaclass = ABCMeta):
                         yield output, chunk_position
                         output = []
                         chunk_position = chunk_start
-                    # Take from chunk_position as far as far as the block can go,
+                    # Take from chunk_position as far as the block can go,
                     # or as much left of a scanner chunk as we can
-                    chunk_size = min(block_end - chunk_position,
-                                     scanner.chunk_size + scanner.overlap - (chunk_position - chunk_start))
+                    chunk_size = min(
+                        block_end - chunk_position,
+                        scanner.chunk_size
+                        + scanner.overlap
+                        - (chunk_position - chunk_start),
+                    )
                     output += [(return_name, chunk_position + conversion, chunk_size)]
                     chunk_start = chunk_position + chunk_size
                     chunk_position = chunk_start
@@ -568,12 +653,20 @@ class LayerContainer(collections.abc.Mapping):
             layer: the layer to add to the list of layers (based on layer.name)
         """
         if layer.name in self._layers:
-            raise exceptions.LayerException(layer.name, f"Layer already exists: {layer.name}")
+            raise exceptions.LayerException(
+                layer.name, f"Layer already exists: {layer.name}"
+            )
         if isinstance(layer, TranslationLayerInterface):
-            missing_list = [sublayer for sublayer in layer.dependencies if sublayer not in self._layers]
+            missing_list = [
+                sublayer
+                for sublayer in layer.dependencies
+                if sublayer not in self._layers
+            ]
             if missing_list:
                 raise exceptions.LayerException(
-                    layer.name, f"Layer {layer.name} has unmet dependencies: {', '.join(missing_list)}")
+                    layer.name,
+                    f"Layer {layer.name} has unmet dependencies: {', '.join(missing_list)}",
+                )
         self._layers[layer.name] = layer
 
     def del_layer(self, name: str) -> None:
@@ -585,11 +678,16 @@ class LayerContainer(collections.abc.Mapping):
             name: The name of the layer to delete
         """
         for layer in self._layers:
-            depend_list = [superlayer for superlayer in self._layers if name in self._layers[layer].dependencies]
+            depend_list = [
+                superlayer
+                for superlayer in self._layers
+                if name in self._layers[layer].dependencies
+            ]
             if depend_list:
                 raise exceptions.LayerException(
                     self._layers[layer].name,
-                    f"Layer {self._layers[layer].name} is depended upon: {', '.join(depend_list)}")
+                    f"Layer {self._layers[layer].name} is depended upon: {', '.join(depend_list)}",
+                )
         self._layers[name].destroy()
         del self._layers[name]
 
