@@ -25,26 +25,34 @@ class Modules(interfaces.plugins.PluginInterface):
     @classmethod
     def get_requirements(cls) -> List[interfaces.configuration.RequirementInterface]:
         return [
-            requirements.ModuleRequirement(name = 'kernel', description = 'Windows kernel',
-                                                     architectures = ["Intel32", "Intel64"]),
-            requirements.VersionRequirement(name = 'pslist', component = pslist.PsList, version = (2, 0, 0)),
-            requirements.VersionRequirement(name = 'dlllist', component = dlllist.DllList, version = (2, 0, 0)),
-            requirements.BooleanRequirement(name = 'dump',
-                                            description = "Extract listed modules",
-                                            default = False,
-                                            optional = True)
+            requirements.ModuleRequirement(
+                name="kernel",
+                description="Windows kernel",
+                architectures=["Intel32", "Intel64"],
+            ),
+            requirements.VersionRequirement(
+                name="pslist", component=pslist.PsList, version=(2, 0, 0)
+            ),
+            requirements.VersionRequirement(
+                name="dlllist", component=dlllist.DllList, version=(2, 0, 0)
+            ),
+            requirements.BooleanRequirement(
+                name="dump",
+                description="Extract listed modules",
+                default=False,
+                optional=True,
+            ),
         ]
 
     def _generator(self):
-        kernel = self.context.modules[self.config['kernel']]
-        pe_table_name = intermed.IntermediateSymbolTable.create(self.context,
-                                                                self.config_path,
-                                                                "windows",
-                                                                "pe",
-                                                                class_types = pe.class_types)
-
-        for mod in self.list_modules(self.context, kernel.layer_name, kernel.symbol_table_name):
+        kernel = self.context.modules[self.config["kernel"]]
+        pe_table_name = intermed.IntermediateSymbolTable.create(
+            self.context, self.config_path, "windows", "pe", class_types=pe.class_types
+        )
 
+        for mod in self.list_modules(
+            self.context, kernel.layer_name, kernel.symbol_table_name
+        ):
             try:
                 BaseDllName = mod.BaseDllName.get_string()
             except exceptions.InvalidAddressException:
@@ -56,22 +64,35 @@ class Modules(interfaces.plugins.PluginInterface):
                 FullDllName = ""
 
             file_output = "Disabled"
-            if self.config['dump']:
-                file_handle = dlllist.DllList.dump_pe(self.context, pe_table_name, mod, self.open)
+            if self.config["dump"]:
+                file_handle = dlllist.DllList.dump_pe(
+                    self.context, pe_table_name, mod, self.open
+                )
                 file_output = "Error outputting file"
                 if file_handle:
                     file_handle.close()
                     file_output = file_handle.preferred_filename
 
-            yield (0, (format_hints.Hex(mod.vol.offset), format_hints.Hex(mod.DllBase),
-                       format_hints.Hex(mod.SizeOfImage), BaseDllName, FullDllName, file_output))
+            yield (
+                0,
+                (
+                    format_hints.Hex(mod.vol.offset),
+                    format_hints.Hex(mod.DllBase),
+                    format_hints.Hex(mod.SizeOfImage),
+                    BaseDllName,
+                    FullDllName,
+                    file_output,
+                ),
+            )
 
     @classmethod
-    def get_session_layers(cls,
-                           context: interfaces.context.ContextInterface,
-                           layer_name: str,
-                           symbol_table: str,
-                           pids: List[int] = None) -> Generator[str, None, None]:
+    def get_session_layers(
+        cls,
+        context: interfaces.context.ContextInterface,
+        layer_name: str,
+        symbol_table: str,
+        pids: List[int] = None,
+    ) -> Generator[str, None, None]:
         """Build a cache of possible virtual layers, in priority starting with
         the primary/kernel layer. Then keep one layer per session by cycling
         through the process list.
@@ -88,10 +109,12 @@ class Modules(interfaces.plugins.PluginInterface):
         seen_ids: List[interfaces.objects.ObjectInterface] = []
         filter_func = pslist.PsList.create_pid_filter(pids or [])
 
-        for proc in pslist.PsList.list_processes(context = context,
-                                                 layer_name = layer_name,
-                                                 symbol_table = symbol_table,
-                                                 filter_func = filter_func):
+        for proc in pslist.PsList.list_processes(
+            context=context,
+            layer_name=layer_name,
+            symbol_table=symbol_table,
+            filter_func=filter_func,
+        ):
             proc_id = "Unknown"
             try:
                 proc_id = proc.UniqueProcessId
@@ -99,9 +122,11 @@ class Modules(interfaces.plugins.PluginInterface):
 
                 # create the session space object in the process' own layer.
                 # not all processes have a valid session pointer.
-                session_space = context.object(symbol_table + constants.BANG + "_MM_SESSION_SPACE",
-                                               layer_name = layer_name,
-                                               offset = proc.Session)
+                session_space = context.object(
+                    symbol_table + constants.BANG + "_MM_SESSION_SPACE",
+                    layer_name=layer_name,
+                    offset=proc.Session,
+                )
 
                 if session_space.SessionId in seen_ids:
                     continue
@@ -110,7 +135,9 @@ class Modules(interfaces.plugins.PluginInterface):
                 vollog.log(
                     constants.LOGLEVEL_VVV,
                     "Process {} does not have a valid Session or a layer could not be constructed for it".format(
-                        proc_id))
+                        proc_id
+                    ),
+                )
                 continue
 
             # save the layer if we haven't seen the session yet
@@ -118,8 +145,12 @@ class Modules(interfaces.plugins.PluginInterface):
             yield proc_layer_name
 
     @classmethod
-    def find_session_layer(cls, context: interfaces.context.ContextInterface, session_layers: Iterable[str],
-                           base_address: int):
+    def find_session_layer(
+        cls,
+        context: interfaces.context.ContextInterface,
+        session_layers: Iterable[str],
+        base_address: int,
+    ):
         """Given a base address and a list of layer names, find a layer that
         can access the specified address.
 
@@ -141,8 +172,12 @@ class Modules(interfaces.plugins.PluginInterface):
         return None
 
     @classmethod
-    def list_modules(cls, context: interfaces.context.ContextInterface, layer_name: str,
-                     symbol_table: str) -> Iterable[interfaces.objects.ObjectInterface]:
+    def list_modules(
+        cls,
+        context: interfaces.context.ContextInterface,
+        layer_name: str,
+        symbol_table: str,
+    ) -> Iterable[interfaces.objects.ObjectInterface]:
         """Lists all the modules in the primary layer.
 
         Args:
@@ -154,8 +189,8 @@ class Modules(interfaces.plugins.PluginInterface):
             A list of Modules as retrieved from PsLoadedModuleList
         """
 
-        kvo = context.layers[layer_name].config['kernel_virtual_offset']
-        ntkrnlmp = context.module(symbol_table, layer_name = layer_name, offset = kvo)
+        kvo = context.layers[layer_name].config["kernel_virtual_offset"]
+        ntkrnlmp = context.module(symbol_table, layer_name=layer_name, offset=kvo)
 
         try:
             # use this type if its available (starting with windows 10)
@@ -166,13 +201,24 @@ class Modules(interfaces.plugins.PluginInterface):
         type_name = ldr_entry_type.type_name.split(constants.BANG)[1]
 
         list_head = ntkrnlmp.get_symbol("PsLoadedModuleList").address
-        list_entry = ntkrnlmp.object(object_type = "_LIST_ENTRY", offset = list_head)
+        list_entry = ntkrnlmp.object(object_type="_LIST_ENTRY", offset=list_head)
         reloff = ldr_entry_type.relative_child_offset("InLoadOrderLinks")
-        module = ntkrnlmp.object(object_type = type_name, offset = list_entry.vol.offset - reloff, absolute = True)
+        module = ntkrnlmp.object(
+            object_type=type_name, offset=list_entry.vol.offset - reloff, absolute=True
+        )
 
         for mod in module.InLoadOrderLinks:
             yield mod
 
     def run(self):
-        return renderers.TreeGrid([("Offset", format_hints.Hex), ("Base", format_hints.Hex), ("Size", format_hints.Hex),
-                                   ("Name", str), ("Path", str), ("File output", str)], self._generator())
+        return renderers.TreeGrid(
+            [
+                ("Offset", format_hints.Hex),
+                ("Base", format_hints.Hex),
+                ("Size", format_hints.Hex),
+                ("Name", str),
+                ("Path", str),
+                ("File output", str),
+            ],
+            self._generator(),
+        )
