@@ -9,36 +9,46 @@ from volatility3.framework import objects, interfaces
 
 
 class elf(objects.StructType):
-    '''
+    """
     Class used to create elf objects. It overrides the typename to `Elf32_` or `Elf64_`,
     depending on the corresponding value on e_ident
-    '''
+    """
 
-    def __init__(self, context: interfaces.context.ContextInterface, type_name: str,
-                 object_info: interfaces.objects.ObjectInformation, size: int,
-                 members: Dict[str, Tuple[int, interfaces.objects.Template]]) -> None:
-
-        super().__init__(context = context,
-                         type_name = type_name,
-                         object_info = object_info,
-                         size = size,
-                         members = members)
+    def __init__(
+        self,
+        context: interfaces.context.ContextInterface,
+        type_name: str,
+        object_info: interfaces.objects.ObjectInformation,
+        size: int,
+        members: Dict[str, Tuple[int, interfaces.objects.Template]],
+    ) -> None:
+        super().__init__(
+            context=context,
+            type_name=type_name,
+            object_info=object_info,
+            size=size,
+            members=members,
+        )
 
         layer_name = self.vol.layer_name
         symbol_table_name = self.get_symbol_table_name()
         # We read the MAGIC: (0x0 to 0x4) 0x7f 0x45 0x4c 0x46
-        magic = self._context.object(symbol_table_name + constants.BANG + "unsigned long",
-                                     layer_name = layer_name,
-                                     offset = object_info.offset)
+        magic = self._context.object(
+            symbol_table_name + constants.BANG + "unsigned long",
+            layer_name=layer_name,
+            offset=object_info.offset,
+        )
 
         # Check validity
-        if magic != 0x464c457f:
+        if magic != 0x464C457F:
             return None
 
         # We need to read the EI_CLASS (0x4 offset)
-        ei_class = self._context.object(symbol_table_name + constants.BANG + "unsigned char",
-                                        layer_name = layer_name,
-                                        offset = object_info.offset + 0x4)
+        ei_class = self._context.object(
+            symbol_table_name + constants.BANG + "unsigned char",
+            layer_name=layer_name,
+            offset=object_info.offset + 0x4,
+        )
 
         if ei_class == 1:
             self._type_prefix = "Elf32_"
@@ -48,18 +58,20 @@ class elf(objects.StructType):
             raise ValueError(f"Unsupported ei_class value {ei_class}")
 
         # Construct the full header
-        self._hdr = self._context.object(symbol_table_name + constants.BANG + self._type_prefix + "Ehdr",
-                                         layer_name = layer_name,
-                                         offset = object_info.offset)
+        self._hdr = self._context.object(
+            symbol_table_name + constants.BANG + self._type_prefix + "Ehdr",
+            layer_name=layer_name,
+            offset=object_info.offset,
+        )
         self._offset = object_info.offset
 
         self._cached_symtab = None
         self._cached_strtab = None
 
     def is_valid(self):
-        '''
+        """
         Determine whether it is a valid object
-        '''
+        """
         return self._type_prefix is not None and self._hdr is not None
 
     def __getattr__(self, name):
@@ -71,17 +83,26 @@ class elf(objects.StructType):
 
     def __dir__(self):
         return self._hdr.__dir__() + [
-            "get_program_headers", "is_valid", "get_section_headers", "get_symbols", "__dir__"
+            "get_program_headers",
+            "is_valid",
+            "get_section_headers",
+            "get_symbols",
+            "__dir__",
         ]
 
     def get_program_headers(self):
         program_headers = self._context.object(
             self.get_symbol_table_name() + constants.BANG + "array",
-            layer_name = self.vol.layer_name,
-            offset = self._offset + self.e_phoff,
-            subtype = self._context.symbol_space.get_type(self.get_symbol_table_name() + constants.BANG +
-                                                          self._type_prefix + "Phdr"),
-            count = self.e_phnum)
+            layer_name=self.vol.layer_name,
+            offset=self._offset + self.e_phoff,
+            subtype=self._context.symbol_space.get_type(
+                self.get_symbol_table_name()
+                + constants.BANG
+                + self._type_prefix
+                + "Phdr"
+            ),
+            count=self.e_phnum,
+        )
 
         for prog_header in program_headers:
             prog_header.parent_e_type = self.e_type
@@ -92,11 +113,16 @@ class elf(objects.StructType):
     def get_section_headers(self):
         section_headers = self._context.object(
             self.get_symbol_table_name() + constants.BANG + "array",
-            layer_name = self.vol.layer_name,
-            offset = self._offset + self.e_shoff,
-            subtype = self._context.symbol_space.get_type(self.get_symbol_table_name() + constants.BANG +
-                                                          self._type_prefix + "Shdr"),
-            count = self.e_shnum)
+            layer_name=self.vol.layer_name,
+            offset=self._offset + self.e_shoff,
+            subtype=self._context.symbol_space.get_type(
+                self.get_symbol_table_name()
+                + constants.BANG
+                + self._type_prefix
+                + "Shdr"
+            ),
+            count=self.e_shnum,
+        )
         return section_headers
 
     def _find_symbols(self):
@@ -107,7 +133,7 @@ class elf(objects.StructType):
         for phdr in self.get_program_headers():
             try:
                 # Find PT_DYNAMIC segment
-                if str(phdr.p_type.description) != 'PT_DYNAMIC':
+                if str(phdr.p_type.description) != "PT_DYNAMIC":
                     continue
             except ValueError:
                 # If the p_type value is outside the ones declared in the enumeration, an
@@ -149,11 +175,16 @@ class elf(objects.StructType):
 
         symtab_arr = self._context.object(
             self.get_symbol_table_name() + constants.BANG + "array",
-            layer_name = self.vol.layer_name,
-            offset = self._cached_symtab,
-            subtype = self._context.symbol_space.get_type(self.get_symbol_table_name() + constants.BANG +
-                                                          self._type_prefix + "Sym"),
-            count = self._cached_numsyms)
+            layer_name=self.vol.layer_name,
+            offset=self._cached_symtab,
+            subtype=self._context.symbol_space.get_type(
+                self.get_symbol_table_name()
+                + constants.BANG
+                + self._type_prefix
+                + "Sym"
+            ),
+            count=self._cached_numsyms,
+        )
 
         for sym in symtab_arr:
             sym.cached_strtab = self._cached_strtab
@@ -161,7 +192,7 @@ class elf(objects.StructType):
 
 
 class elf_sym(objects.StructType):
-    """ An elf symbol entry"""
+    """An elf symbol entry"""
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -179,13 +210,13 @@ class elf_sym(objects.StructType):
         addr = self._cached_strtab + self.st_name
 
         # Just get the first 255 characters, it should be enough for a symbol name
-        name_bytes = self._context.layers[self.vol.layer_name].read(addr, 255, pad = True)
+        name_bytes = self._context.layers[self.vol.layer_name].read(addr, 255, pad=True)
 
         if name_bytes:
             idx = name_bytes.find(b"\x00")
             if idx != -1:
                 name_bytes = name_bytes[:idx]
-            return name_bytes.decode('utf-8', errors = 'ignore')
+            return name_bytes.decode("utf-8", errors="ignore")
         else:
             # If we cannot read the name from the address space,
             # we return None.
@@ -193,7 +224,7 @@ class elf_sym(objects.StructType):
 
 
 class elf_phdr(objects.StructType):
-    """ An elf program header """
+    """An elf program header"""
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -236,7 +267,7 @@ class elf_phdr(objects.StructType):
     def dynamic_sections(self):
         # sanity check
         try:
-            if str(self.p_type.description) != 'PT_DYNAMIC':
+            if str(self.p_type.description) != "PT_DYNAMIC":
                 return None
         except ValueError:
             # If the value is outside the ones declared in the enumeration, an
@@ -248,17 +279,19 @@ class elf_phdr(objects.StructType):
 
         symbol_table_name = self.get_symbol_table_name()
 
-        rtsize = self._context.symbol_space.get_type(symbol_table_name + \
-                                                     constants.BANG + \
-                                                     self._type_prefix + "Dyn").size
+        rtsize = self._context.symbol_space.get_type(
+            symbol_table_name + constants.BANG + self._type_prefix + "Dyn"
+        ).size
 
         for i in range(256):
             # use the real size
             idx = i * rtsize
 
-            dyn = self._context.object(symbol_table_name + constants.BANG + self._type_prefix + "Dyn",
-                                       layer_name = self.vol.layer_name,
-                                       offset = arr_start + idx)
+            dyn = self._context.object(
+                symbol_table_name + constants.BANG + self._type_prefix + "Dyn",
+                layer_name=self.vol.layer_name,
+                offset=arr_start + idx,
+            )
 
             yield dyn
 
@@ -266,4 +299,10 @@ class elf_phdr(objects.StructType):
                 break
 
 
-class_types = {'Elf': elf, 'Elf64_Phdr': elf_phdr, 'Elf32_Phdr': elf_phdr, 'Elf32_Sym': elf_sym, 'Elf64_Sym': elf_sym}
+class_types = {
+    "Elf": elf,
+    "Elf64_Phdr": elf_phdr,
+    "Elf32_Phdr": elf_phdr,
+    "Elf32_Sym": elf_sym,
+    "Elf64_Sym": elf_sym,
+}
