@@ -1,22 +1,25 @@
 # This file is Copyright 2019 Volatility Foundation and licensed under the Volatility Software License 1.0
 # which is available at https://www.volatilityfoundation.org/license/vsl-v1.0
 #
-
+import contextlib
+import logging
 from typing import Generator, Iterable, Optional, Set, Tuple
 
-from volatility3.framework import constants, objects, renderers
-from volatility3.framework import exceptions, interfaces
+from volatility3.framework import constants, exceptions, interfaces, objects
 from volatility3.framework.objects import utility
 from volatility3.framework.renderers import conversion
 from volatility3.framework.symbols import generic
 
+vollog = logging.getLogger(__name__)
+
 
 class proc(generic.GenericIntelProcess):
-
     def get_task(self):
         return self.task.dereference().cast("task")
 
-    def add_process_layer(self, config_prefix: str = None, preferred_name: str = None) -> Optional[str]:
+    def add_process_layer(
+        self, config_prefix: str = None, preferred_name: str = None
+    ) -> Optional[str]:
         """Constructs a new layer based on the process's DTB.
 
         Returns the name of the Layer or None.
@@ -24,34 +27,53 @@ class proc(generic.GenericIntelProcess):
         parent_layer = self._context.layers[self.vol.layer_name]
 
         if not isinstance(parent_layer, interfaces.layers.TranslationLayerInterface):
-            raise TypeError("Parent layer is not a translation layer, unable to construct process layer")
+            raise TypeError(
+                "Parent layer is not a translation layer, unable to construct process layer"
+            )
 
         try:
             dtb = self.get_task().map.pmap.pm_cr3
         except exceptions.InvalidAddressException:
+            # Bail out because we couldn't find the DTB
             return None
 
         if preferred_name is None:
-            preferred_name = self.vol.layer_name + "_Process{}".format(self.p_pid)
+            preferred_name = self.vol.layer_name + f"_Process{self.p_pid}"
 
         # Add the constructed layer and return the name
-        return self._add_process_layer(self._context, dtb, config_prefix, preferred_name)
+        return self._add_process_layer(
+            self._context, dtb, config_prefix, preferred_name
+        )
 
     def get_map_iter(self) -> Iterable[interfaces.objects.ObjectInterface]:
         try:
             task = self.get_task()
-        except exceptions.InvalidAddressException:
-            return
-
-        try:
             current_map = task.map.hdr.links.next
         except exceptions.InvalidAddressException:
             return
 
-        seen = set()  # type: Set[int]
+        seen: Set[int] = set()
 
         for i in range(task.map.hdr.nentries):
-            if not current_map or current_map.vol.offset in seen:
+            if (
+                not current_map
+                or current_map.vol.offset in seen
+                or not self._context.layers[task.vol.native_layer_name].is_valid(
+                    current_map.dereference().vol.offset,
+                    current_map.dereference().vol.size,
+                )
+            ):
+                vollog.log(
+                    constants.LOGLEVEL_VVV,
+                    "Breaking process maps iteration due to invalid state.",
+                )
+                break
+
+            # ZP_POISON value used to catch programming errors
+            if (
+                current_map.links.start == 0xDEADBEEFDEADBEEF
+                or current_map.links.end == 0xDEADBEEFDEADBEEF
+            ):
                 break
 
             yield current_map
@@ -64,11 +86,12 @@ class proc(generic.GenericIntelProcess):
     # the fix for linux was to call int() so that we were not returning vol objects.
     # I call int() on these and the code works nearly 1-1 with the linux one so I am very confused
     ######
-    def get_process_memory_sections(self,
-                                    context: interfaces.context.ContextInterface,
-                                    config_prefix: str,
-                                    rw_no_file: bool = False) -> \
-            Generator[Tuple[int, int], None, None]:
+    def get_process_memory_sections(
+        self,
+        context: interfaces.context.ContextInterface,
+        config_prefix: str,
+        rw_no_file: bool = False,
+    ) -> Generator[Tuple[int, int], None, None]:
         """Returns a list of sections based on the memory manager's view of
         this task's virtual memory."""
         for vma in self.get_map_iter():
@@ -76,7 +99,10 @@ class proc(generic.GenericIntelProcess):
             end = int(vma.links.end)
 
             if rw_no_file:
-                if vma.get_perms() != "rw" or vma.get_path(context, config_prefix) != "":
+                if (
+                    vma.get_perms() != "rw"
+                    or vma.get_path(context, config_prefix) != ""
+                ):
                     if vma.get_special_path() != "[heap]":
                         continue
 
@@ -84,17 +110,14 @@ class proc(generic.GenericIntelProcess):
 
 
 class fileglob(objects.StructType):
-
     def get_fg_type(self):
         ret = None
 
         if self.has_member("fg_type"):
             ret = self.fg_type
         elif self.fg_ops != 0:
-            try:
+            with contextlib.suppress(exceptions.InvalidAddressException):
                 ret = self.fg_ops.fo_type
-            except exceptions.InvalidAddressException:
-                pass
 
         if ret:
             ret = str(ret.description).replace("DTYPE_", "")
@@ -103,7 +126,6 @@ class fileglob(objects.StructType):
 
 
 class vm_map_object(objects.StructType):
-
     def get_map_object(self):
         if self.has_member("vm_object"):
             return self.vm_object
@@ -114,17 +136,23 @@ class vm_map_object(objects.StructType):
 
 
 class vnode(objects.StructType):
-
     def _do_calc_path(self, ret, vnodeobj, vname):
         if vnodeobj is None:
             return
 
         if vname:
-            ret.append(utility.pointer_to_string(vname, 255))
+            try:
+                ret.append(utility.pointer_to_string(vname, 255))
+            except exceptions.InvalidAddressException:
+                return
 
         if int(vnodeobj.v_flag) & 0x000001 != 0 and int(vnodeobj.v_mount) != 0:
             if int(vnodeobj.v_mount.mnt_vnodecovered) != 0:
-                self._do_calc_path(ret, vnodeobj.v_mount.mnt_vnodecovered, vnodeobj.v_mount.mnt_vnodecovered.v_name)
+                self._do_calc_path(
+                    ret,
+                    vnodeobj.v_mount.mnt_vnodecovered,
+                    vnodeobj.v_mount.mnt_vnodecovered.v_name,
+                )
         else:
             try:
                 parent = vnodeobj.v_parent
@@ -135,7 +163,11 @@ class vnode(objects.StructType):
             self._do_calc_path(ret, parent, parent_name)
 
     def full_path(self):
-        if self.v_flag & 0x000001 != 0 and self.v_mount != 0 and self.v_mount.mnt_flag & 0x00004000 != 0:
+        if (
+            self.v_flag & 0x000001 != 0
+            and self.v_mount != 0
+            and self.v_mount.mnt_flag & 0x00004000 != 0
+        ):
             ret = b"/"
         else:
             elements = []
@@ -155,7 +187,6 @@ class vnode(objects.StructType):
 
 
 class vm_map_entry(objects.StructType):
-
     def is_suspicious(self, context, config_prefix):
         """Flags memory regions that are mapped rwx or that map an executable
         not back from a file on disk."""
@@ -175,7 +206,7 @@ class vm_map_entry(objects.StructType):
         permask = "rwx"
         perms = ""
 
-        for (ctr, i) in enumerate([1, 3, 5]):
+        for ctr, i in enumerate([1, 3, 5]):
             if (self.protection & i) == i:
                 perms = perms + permask[ctr]
             else:
@@ -187,7 +218,7 @@ class vm_map_entry(objects.StructType):
         if self.has_member("alias"):
             ret = int(self.alias)
         else:
-            ret = int(self.vme_offset) & 0xfff
+            ret = int(self.vme_offset) & 0xFFF
 
         return ret
 
@@ -210,10 +241,21 @@ class vm_map_entry(objects.StructType):
             ret = node
         elif node:
             path = []
-            while node:
-                v_name = utility.pointer_to_string(node.v_name, 255)
+            seen: Set[int] = set()
+            while node and node.vol.offset not in seen:
+                try:
+                    v_name = utility.pointer_to_string(node.v_name, 255)
+                except exceptions.InvalidAddressException:
+                    break
+
                 path.append(v_name)
+                if len(path) > 1024:
+                    break
+
+                seen.add(node.vol.offset)
+
                 node = node.v_parent
+
             path.reverse()
             ret = "/" + "/".join(path)
         else:
@@ -243,9 +285,10 @@ class vm_map_entry(objects.StructType):
 
         # based on find_vnode_object
         vnode_object = self.get_object().get_map_object()
+        if vnode_object == 0:
+            return None
 
         found_end = False
-
         while not found_end:
             try:
                 tmp_vnode_object = vnode_object.shadow.dereference()
@@ -257,8 +300,15 @@ class vm_map_entry(objects.StructType):
             else:
                 vnode_object = tmp_vnode_object
 
+        if vnode_object.vol.offset == 0:
+            return None
+
         try:
-            ops = vnode_object.pager.mo_pager_ops.dereference()
+            pager = vnode_object.pager
+            if pager == 0:
+                return None
+
+            ops = pager.mo_pager_ops.dereference()
         except exceptions.InvalidAddressException:
             return None
 
@@ -269,9 +319,11 @@ class vm_map_entry(objects.StructType):
                 break
 
         if found:
-            vpager = context.object(config_prefix + constants.BANG + "vnode_pager",
-                                    layer_name = vnode_object.vol.native_layer_name,
-                                    offset = vnode_object.pager)
+            vpager = context.object(
+                config_prefix + constants.BANG + "vnode_pager",
+                layer_name=vnode_object.vol.native_layer_name,
+                offset=vnode_object.pager,
+            )
             ret = vpager.vnode_handle
         else:
             ret = None
@@ -280,7 +332,6 @@ class vm_map_entry(objects.StructType):
 
 
 class socket(objects.StructType):
-
     def get_inpcb(self):
         try:
             ret = self.so_pcb.dereference().cast("inpcb")
@@ -338,10 +389,20 @@ class socket(objects.StructType):
 
 
 class inpcb(objects.StructType):
-
     def get_tcp_state(self):
-        tcp_states = ("CLOSED", "LISTEN", "SYN_SENT", "SYN_RECV", "ESTABLISHED", "CLOSE_WAIT", "FIN_WAIT1", "CLOSING",
-                      "LAST_ACK", "FIN_WAIT2", "TIME_WAIT")
+        tcp_states = (
+            "CLOSED",
+            "LISTEN",
+            "SYN_SENT",
+            "SYN_RECV",
+            "ESTABLISHED",
+            "CLOSE_WAIT",
+            "FIN_WAIT1",
+            "CLOSING",
+            "LAST_ACK",
+            "FIN_WAIT2",
+            "TIME_WAIT",
+        )
 
         try:
             tcpcb = self.inp_ppcb.dereference().cast("tcpcb")
@@ -375,14 +436,18 @@ class inpcb(objects.StructType):
 
     def get_ipv6_info(self):
         try:
-            lip = self.inp_dependladdr.inp6_local.member(attr = '__u6_addr').member(attr = '__u6_addr32')
+            lip = self.inp_dependladdr.inp6_local.member(attr="__u6_addr").member(
+                attr="__u6_addr32"
+            )
         except exceptions.InvalidAddressException:
             return None
 
         lport = self.inp_lport
 
         try:
-            rip = self.inp_dependfaddr.inp6_foreign.member(attr = '__u6_addr').member(attr = '__u6_addr32')
+            rip = self.inp_dependfaddr.inp6_foreign.member(attr="__u6_addr").member(
+                attr="__u6_addr32"
+            )
         except exceptions.InvalidAddressException:
             return None
 
@@ -392,12 +457,13 @@ class inpcb(objects.StructType):
 
 
 class queue_entry(objects.StructType):
-
-    def walk_list(self,
-                  list_head: interfaces.objects.ObjectInterface,
-                  member_name: str,
-                  type_name: str,
-                  max_size: int = 4096) -> Iterable[interfaces.objects.ObjectInterface]:
+    def walk_list(
+        self,
+        list_head: interfaces.objects.ObjectInterface,
+        member_name: str,
+        type_name: str,
+        max_size: int = 4096,
+    ) -> Iterable[interfaces.objects.ObjectInterface]:
         """
         Walks a queue in a smear-aware and smear-resistant manner
 
@@ -422,8 +488,8 @@ class queue_entry(objects.StructType):
 
         seen = set()
 
-        for attr in ['next', 'prev']:
-            try:
+        for attr in ["next", "prev"]:
+            with contextlib.suppress(exceptions.InvalidAddressException):
                 n = getattr(self, attr).dereference().cast(type_name)
 
                 while n is not None and n.vol.offset != list_head:
@@ -438,14 +504,14 @@ class queue_entry(objects.StructType):
                     if yielded == max_size:
                         return
 
-                    n = getattr(n.member(attr = member_name), attr).dereference().cast(type_name)
-
-            except exceptions.InvalidAddressException:
-                pass
+                    n = (
+                        getattr(n.member(attr=member_name), attr)
+                        .dereference()
+                        .cast(type_name)
+                    )
 
 
 class ifnet(objects.StructType):
-
     def sockaddr_dl(self):
         if self.has_member("if_lladdr"):
             try:
@@ -454,7 +520,9 @@ class ifnet(objects.StructType):
                 val = None
         else:
             try:
-                val = self.if_addrhead.tqh_first.ifa_addr.dereference().cast("sockaddr_dl")
+                val = self.if_addrhead.tqh_first.ifa_addr.dereference().cast(
+                    "sockaddr_dl"
+                )
             except exceptions.InvalidAddressException:
                 val = None
 
@@ -463,7 +531,6 @@ class ifnet(objects.StructType):
 
 # this is used for MAC addresses
 class sockaddr_dl(objects.StructType):
-
     def __str__(self):
         ret = ""
 
@@ -478,7 +545,7 @@ class sockaddr_dl(objects.StructType):
 
             e = e.cast("unsigned char")
 
-            ret = ret + "{:02X}:".format(e)
+            ret = ret + f"{e:02X}:"
 
         if ret and ret[-1] == ":":
             ret = ret[:-1]
@@ -487,7 +554,6 @@ class sockaddr_dl(objects.StructType):
 
 
 class sockaddr(objects.StructType):
-
     def get_address(self):
         ip = ""
 
@@ -498,7 +564,9 @@ class sockaddr(objects.StructType):
 
         elif family == 30:  # AF_INET6
             addr_in6 = self.cast("sockaddr_in6")
-            ip = conversion.convert_ipv6(addr_in6.sin6_addr.member(attr = "__u6_addr").member(attr = "__u6_addr32"))
+            ip = conversion.convert_ipv6(
+                addr_in6.sin6_addr.member(attr="__u6_addr").member(attr="__u6_addr32")
+            )
 
         elif family == 18:  # AF_LINK
             addr_dl = self.cast("sockaddr_dl")
@@ -508,7 +576,6 @@ class sockaddr(objects.StructType):
 
 
 class sysctl_oid(objects.StructType):
-
     def get_perms(self) -> str:
         """
         Returns the actions allowed on the node
@@ -526,7 +593,7 @@ class sysctl_oid(objects.StructType):
         checks = [0x80000000, 0x40000000, 0x00800000]
         perms = ["R", "W", "L"]
 
-        for (i, c) in enumerate(checks):
+        for i, c in enumerate(checks):
             if c & self.oid_kind:
                 ret = ret + perms[i]
             else:
@@ -551,9 +618,15 @@ class sysctl_oid(objects.StructType):
 
         Based on sysctl_sysctl_debug_dump_node
         """
-        types = {1: 'CTLTYPE_NODE', 2: 'CTLTYPE_INT', 3: 'CTLTYPE_STRING', 4: 'CTLTYPE_QUAD', 5: 'CTLTYPE_OPAQUE'}
+        types = {
+            1: "CTLTYPE_NODE",
+            2: "CTLTYPE_INT",
+            3: "CTLTYPE_STRING",
+            4: "CTLTYPE_QUAD",
+            5: "CTLTYPE_OPAQUE",
+        }
 
-        ctltype = self.oid_kind & 0xf
+        ctltype = self.oid_kind & 0xF
 
         if 0 < ctltype < 6:
             ret = types[ctltype]
@@ -564,7 +637,6 @@ class sysctl_oid(objects.StructType):
 
 
 class kauth_scope(objects.StructType):
-
     def get_listeners(self):
         for listener in self.ks_listeners:
             if listener != 0 and listener.kll_callback != 0:
